@@ -8,14 +8,13 @@
 # or in the "LICENSE.txt" file accompanying this file. This file is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES
 # OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions and
 # limitations under the License.
-from future.moves.collections import OrderedDict
-
 import errno
 import json
 import logging
 import os
 import stat
 import sys
+from collections import OrderedDict
 
 import boto3
 import configparser
@@ -26,6 +25,7 @@ from pcluster.config.cfn_param_types import ClusterCfnSection
 from pcluster.config.mappings import ALIASES, AWS, GLOBAL
 from pcluster.config.param_types import StorageData
 from pcluster.utils import (
+    InstanceTypeInfo,
     get_cfn_param,
     get_file_section_name,
     get_installed_version,
@@ -101,6 +101,9 @@ class PclusterConfig(object):
         else:
             self.__init_sections_from_file(cluster_label, self.config_parser, fail_on_file_absence)
 
+        # Load instance types data if available
+        self.__init_additional_instance_types_data()
+
         self.__autorefresh = auto_refresh  # Initialization completed
 
         # Refresh sections and parameters
@@ -587,3 +590,9 @@ class PclusterConfig(object):
         config_metadata_param = self.get_section("cluster").get_param("cluster_config_metadata")
         self.__sections = pcluster_config.__sections
         self.get_section("cluster").set_param("cluster_config_metadata", config_metadata_param)
+
+    def __init_additional_instance_types_data(self):
+        """Store additional instance type information coming from instance_types_data parameter."""
+        InstanceTypeInfo.load_additional_instance_types_data(
+            self.get_section("cluster").get_param_value("instance_types_data")
+        )
